Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(238)

Unified Diff: util/posix/symbolic_constants_posix_test.cc

Issue 656703002: Convert NULL to nullptr (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Fix 80-column violations Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « util/posix/symbolic_constants_posix.cc ('k') | util/synchronization/semaphore_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: util/posix/symbolic_constants_posix_test.cc
diff --git a/util/posix/symbolic_constants_posix_test.cc b/util/posix/symbolic_constants_posix_test.cc
index c80d00d9e522b9e1870c132794a44185f1d37174..db3193d45e1840bea680b305baf2610fd3eeceec 100644
--- a/util/posix/symbolic_constants_posix_test.cc
+++ b/util/posix/symbolic_constants_posix_test.cc
@@ -69,7 +69,7 @@ const struct {
#endif
};
// If |expect| is NULL, the conversion is expected to fail. If |expect| is
// empty, the conversion is expected to succeed, but the precise returned string
// value is unknown. Otherwise, the conversion is expected to succeed, and
// |expect| contains the precise expected string value to be returned.
@@ -130,7 +130,7 @@ TEST(SymbolicConstantsPOSIX, SignalToString) {
if (signal > 0 && signal < kSignalCount) {
TestSignalToString(signal, "", "");
} else {
- TestSignalToString(signal, NULL, NULL);
+ TestSignalToString(signal, nullptr, nullptr);
}
}
}
@@ -69,7 +69,7 @@ const struct {
#endif
};
-// If |expect| is NULL, the conversion is expected to fail. If |expect| is
+// If |expect| is nullptr, the conversion is expected to fail. If |expect| is
// empty, the conversion is expected to succeed, but the precise returned string
// value is unknown. Otherwise, the conversion is expected to succeed, and
« no previous file with comments | « util/posix/symbolic_constants_posix.cc ('k') | util/synchronization/semaphore_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698